/**
 * @since 1.0.0
 */
import type * as babel from "@babel/core";
/**
 * The configuration options for `@effect/babel-plugin`.
 *
 * @since 1.0.0
 * @category models
 */
export interface PluginConfig {
    /**
     * Rewrites calls to `pipe` to directly call the piped functions.
     *
     * By default, the plugin will only rewrite calls to `pipe` imported from
     * `@fp-ts/core/Function`. However, the `targetImports` configuration option
     * can be used to allow the plugin to rewrite calls to `pipe` imported from
     * custom paths.
     */
    readonly rewritePipe?: false | {
        targetImports: ReadonlyArray<string>;
    };
    /**
     * Rewrites calls to `identity` to remove them entirely.
     *
     * By default, the plugin will only rewrite calls to `identity` imported from
     * `@fp-ts/core/Function`. However, the `targetImports` configuration option
     * can be used to allow the plugin to rewrite calls to `identity` imported
     * from custom paths.
     */
    readonly rewriteIdentity?: false | {
        targetImports: ReadonlyArray<string>;
    };
}
declare const plugin: ({ types: t }: typeof babel, options: PluginConfig) => babel.PluginObj<PluginConfig>;
/**
 * The `@effect/babel-plugin` plugin.
 *
 * @since 1.0.0
 * @category plugin
 */
export default plugin;
//# sourceMappingURL=index.d.ts.map